# NiWrap Helper

Utility library to help make working with [NiWrap] + [`bids2table`] easier.

> [!IMPORTANT]
> Version `0.2.x` is incompatible with `0.1.x` due to breaking changes in 
> [`bids2table`]. Any previously created indices will **need** to be recreated.

<!-- Links -->
[`bids2table`]: https://github.com/childmindresearch/bids2table
[NiWrap]: https://styx-api.github.io/
